@@ -216,7 +216,8 @@ gint gok_button_enter_notify   (GtkWidget *widget, GdkEventCrossing   *event)
 	pKey = gok_button_find_key (widget);
 	if (pKey != NULL)
 	{
-		if (!strcmp (gok_data_get_name_accessmethod (), "dwellselection")) 
+		if (!gok_main_get_login() &&
+			!strcmp (gok_data_get_name_accessmethod (), "dwellselection")) 
 		{
 		    gok_main_warn_corepointer (TRUE, FALSE, FALSE);
 		}
