@@ -98,14 +98,20 @@ gok_input_extension_filter (GdkXEvent *gdk_xevent, GdkEvent *event, gpointer dat
 	if (xevent->type == gok_input_types[GOK_INPUT_TYPE_MOTION])
 	{
 		XDeviceMotionEvent *motion = (XDeviceMotionEvent *) xevent;
-		if (gok_input_get_current() &&
+		if (!gok_input_get_current() ||
 		    motion->deviceid != gok_input_get_current ()->device->device_id)
 		{
-			GokInput *input = gok_input_find_by_device_id (motion->deviceid, TRUE);
-			if (input) gok_input_mismatch_warn (input->info);
+		        gok_log ("motion event from unexpected device...\n");
+			GokInput *input;
+			if (gok_main_attach_new_devices ()) {
+			  input = gok_input_find_by_device_id (motion->deviceid, TRUE);
+			  if (input) gok_input_mismatch_warn (input->info);
+			}
+		}
+		else {
+		  gok_main_motion_listener (motion->axes_count, motion->axis_data, 
+					    motion->device_state, (long) motion->time);
 		}
-		gok_main_motion_listener (motion->axes_count, motion->axis_data, 
-					  motion->device_state, (long) motion->time);
 	}
 	else if ((xevent->type == gok_input_types[GOK_INPUT_TYPE_BUTTON_PRESS]) || 
 		 (xevent->type == gok_input_types[GOK_INPUT_TYPE_BUTTON_RELEASE]))
@@ -120,7 +126,8 @@ gok_input_extension_filter (GdkXEvent *gdk_xevent, GdkEvent *event, gpointer dat
 		gok_main_button_listener (button->button, 
 					  (xevent->type == gok_input_types[GOK_INPUT_TYPE_BUTTON_PRESS]) ? 1 : 0, 
 					  button->state, 
-					  button->time);
+					  button->time,
+					  FALSE);
 	}
 	else 
 	{
@@ -305,8 +312,8 @@ gok_input_get_device_list (void)
 			      pInput = g_new0 (GokInput, 1);
 			      pInput->name = g_strdup (devices[i].name);
 			      pInput->info = &devices[i];
-			      gok_input_open (pInput);
-			      input_device_list = g_slist_prepend (input_device_list, pInput);
+			      if (gok_input_open (pInput))
+				input_device_list = g_slist_prepend (input_device_list, pInput);
 			  }
 		  }
 	  }
@@ -373,20 +380,20 @@ gok_input_init (GdkFilterFunc filter_func)
 		if (!input->open && !gok_input_open (input)) {
 			g_warning ("Cannot open input device!\n");
 		}
-
-		number = gok_input_init_device_event_list (input->info, input->device, event_list);
-		root = gdk_screen_get_root_window (gdk_drawable_get_screen (window->window));
+		else {
+		  number = gok_input_init_device_event_list (input->info, input->device, event_list);
+		  root = gdk_screen_get_root_window (gdk_drawable_get_screen (window->window));
 	
-		if (XSelectExtensionEvent(GDK_WINDOW_XDISPLAY (root), 
-					  GDK_WINDOW_XWINDOW (root),
-					  event_list, number)) 
-		{
+		  if (XSelectExtensionEvent(GDK_WINDOW_XDISPLAY (root), 
+					    GDK_WINDOW_XWINDOW (root),
+					    event_list, number)) 
+		  {
 		    g_warning ("Can't connect to input device!");
-		}
-	
+		  }
+		}	
 		device_list = device_list->next;
 	}
-	printf ("%d event types available\n", number);
+	gok_log ("%d event types available\n", number);
 	
 	gdk_window_add_filter (NULL,
 			       filter_func,
@@ -400,6 +407,7 @@ gok_input_init (GdkFilterFunc filter_func)
 gboolean
 gok_input_set_extension_device_by_name (char *name)
 {
+        gok_log ("SETTING INPUT DEVICE TO %s\n", name);
 	gok_gconf_set_string (gconf_client_get_default(), 
 			      GOK_GCONF_INPUT_DEVICE,
 			      name);
@@ -501,12 +509,14 @@ GokInput * gok_input_get_current (void)
 	  current_input = gok_input_find_by_name (input_device_name, TRUE);
       }
   }
+  gok_log ("current input device=%x\n", current_input);
   return current_input;
 }
 
 void
 gok_input_restore (void)
 {
+        gok_log (stderr, "gok input restore\n");
 	gok_input_set_extension_device_by_name (saved_input_device);
 	gok_input_close_others (); 
 }
@@ -517,6 +527,7 @@ gok_input_mismatch_warn (XDeviceInfo *device)
 	gchar *message = g_strdup_printf (_("GOK has detected activity from a new hardware device named \'%s\'.  "
 					    "Would you like to use this device instead of device \'%s\'?"),
 					  device->name, gok_input_get_extension_device_name ());
+	fprintf (stderr, "%s", message);
 	saved_input_device = gok_input_get_extension_device_name ();
 	gok_input_set_extension_device_by_name (device->name);
 	gok_main_warn (message, TRUE, gok_input_restore, gok_input_close_others, FALSE);
