@@ -1166,19 +1166,21 @@ gok_main_object_state_listener (Accessible* pAccessible)
 				   is represented properly. TODO: generalize
 				*/
 				ass = Accessible_getStateSet(pAccessible);
-				if (AccessibleStateSet_contains( ass, SPI_STATE_CHECKED )) {
+				if (ass) { 
+				 if (AccessibleStateSet_contains( ass, SPI_STATE_CHECKED )) {
 					pK->ComponentState.active = TRUE;
-				}
-				else {
+				 }
+				 else {
 					pK->ComponentState.active = FALSE;
-				}
-				if (!AccessibleStateSet_contains( ass, SPI_STATE_ENABLED ))
-				{
+				 }
+				 if (!AccessibleStateSet_contains( ass, SPI_STATE_ENABLED ))
+				 {
 					pK->Style = KEYSTYLE_INSENSITIVE;
 					gok_key_set_button_name (pK);
+				 }
+				 AccessibleStateSet_unref(ass);
+				 gok_key_update_toggle_state (pK);
 				}
-				AccessibleStateSet_unref(ass);
-				gok_key_update_toggle_state (pK);
 				/* unfortunately, another special case for now... */
 				if (Accessible_getRole (pAccessible) == SPI_ROLE_PAGE_TAB) 
 				{
